@@ -607,9 +607,16 @@ sub arch {
 			# Treat armv4l as arm.
 			$arch='arm';
 		}
+		elsif ($arch eq 'armv7l') {
+			# Treat armv7l as armel.
+			$arch='armel';
+		}
 		elsif ($arch eq 'parisc') {
 			$arch='hppa';
 		}
+		elsif ($arch eq 'ppc64le') {
+			$arch='ppc64el';
+		}
 		
 		$this->{arch}=$arch;
 	}
@@ -629,6 +636,9 @@ sub arch {
 	elsif ($arch eq 'all') {
 		$arch='noarch';
 	}
+	elsif ($arch eq 'ppc64el') {
+		$arch='ppc64le';
+	}
 
 	return $arch
 }
