@@ -118,7 +118,7 @@ sub scan {
 	$this->group("unknown");
 	$this->origformat('tgz');
 	$this->changelogtext('');
-	$this->binary_info($this->runpipe(0, "ls -l $file"));
+	$this->binary_info($this->runpipe(0, "ls -l '$file'"));
 
 	# Now figure out the conffiles. Assume anything in etc/ is a
 	# conffile.
@@ -152,7 +152,7 @@ sub scan {
 
 	# Now get the scripts.
 	foreach my $script (keys %{scripttrans()}) {
-		$this->$script(scalar $this->runpipe(1, "tar Oxf $file install/${scripttrans()}{$script} 2>/dev/null"));
+		$this->$script(scalar $this->runpipe(1, "tar Oxf '$file' install/${scripttrans()}{$script} 2>/dev/null"));
 	}
 
 	return 1;
